@@ -13,8 +13,9 @@ from fa_purity.json.primitive.factory import (
 from fa_purity.utils import (
     raise_exception,
 )
-from redshift_client.schema.core import (
+from redshift_client.id_objs import (
     SchemaId,
+    TableId,
 )
 from redshift_client.sql_client.core import (
     InvalidType,
@@ -24,9 +25,6 @@ from redshift_client.sql_client.query import (
     dynamic_query,
     new_query,
 )
-from redshift_client.table.core import (
-    TableId,
-)
 from typing import (
     FrozenSet,
     TypeVar,
