@@ -4,15 +4,12 @@ from dataclasses import (
 from fa_purity.frozen import (
     FrozenDict,
 )
-from redshift_client.table.core import (
-    Table,
+from redshift_client.id_objs import (
     TableId,
 )
-
-
-@dataclass(frozen=True)
-class SchemaId:
-    name: str
+from redshift_client.table.core import (
+    Table,
+)
 
 
 @dataclass(frozen=True)
