@@ -12,21 +12,12 @@ from redshift_client.column import (
     Column,
     ColumnId,
 )
-from redshift_client.schema.core import (
-    SchemaId,
-)
 from typing import (
     Callable,
     FrozenSet,
 )
 
 
-@dataclass(frozen=True)
-class TableId:
-    schema: SchemaId
-    name: str
-
-
 @dataclass(frozen=True)
 class _Table:
     columns: FrozenDict[ColumnId, Column]
